CATEResult

Conditional average treatment effect estimates.

Usage

CATEResult(
    x,
    cate,
    se,
    lower,
    upper,
    variable,
    level,
)

Returned by CausalGAM.cate() when the model was fit with method="interactive". Represents the treatment effect as a smooth function of one confounder variable, evaluated on a grid (or on user-supplied covariate data), together with pointwise confidence bands.

Attributes

x: NDArray

Covariate values of variable at which CATE is evaluated.

cate: NDArray

CATE estimates, tau(x) = E[Y(1) - Y(0) | X = x], at each value of x.

se: NDArray

Standard errors of the CATE estimates.

lower: NDArray

Lower pointwise confidence bounds, cate - z * se.

upper: NDArray

Upper pointwise confidence bounds, cate + z * se.

variable: str

Name of the conditioning (confounder) variable that CATE is plotted against.

level: float
Confidence level used for the bands.