MultiResponseResult
Prediction result for multiple responses.
Usage
MultiResponseResult(
predictions,
responses,
)Returned by MultiResponseGAM.predict(). Behaves like a dict keyed by response name (via __getitem__) and iterates over response names (via __iter__), while retaining the ordered list of responses for convenience.
Attributes
predictions: dict[str, PredictionResult]-
Dict mapping response name to its PredictionResult (values, optional standard errors, and linear predictor) from that response’s individual GAM.
responses: list[str]- List of response names (ordered), matching the order passed to MultiResponseGAM.